/* Copyright (C) 2023 FIAS Frankfurt Institute for Advanced Studies, Frankfurt / Main
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Felix Weiglhofer [committer] */
#ifndef CBM_ALGO_GLOBAL_ARCHIVE_DESCRIPTOR_H
#define CBM_ALGO_GLOBAL_ARCHIVE_DESCRIPTOR_H

#include "System.hpp"

#include <boost/serialization/access.hpp>
#include <boost/serialization/version.hpp>

#include <chrono>
#include <string>

namespace cbm::algo
{

  class ArchiveDescriptor {

  public:
    ArchiveDescriptor()
      : fTimeCreated(std::chrono::system_clock::to_time_t(std::chrono::system_clock::now()))
      , fHostname(fles::system::current_hostname())
      , fUsername(fles::system::current_username())
    {
    }

    std::time_t TimeCreated() const { return fTimeCreated; }
    const std::string& Hostname() const { return fHostname; }
    const std::string& Username() const { return fUsername; }

  private:  // members
    std::time_t fTimeCreated = std::time_t();
    std::string fHostname;
    std::string fUsername;

  private:  // serialization
    friend class boost::serialization::access;

    template<class Archive>
    void serialize(Archive& ar, const unsigned int /*version*/)
    {
      ar& fTimeCreated;
      ar& fHostname;
      ar& fUsername;
    }
  };

}  // namespace cbm::algo

#endif  // CBM_ALGO_GLOBAL_ARCHIVE_DESCRIPTOR_H
